﻿using WpfAudioPlayer.Models.Audio;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音声のコーラス効果の View と Model を仲介するクラスです。
	/// </summary>
	class EffectChorusViewModel : EffectViewModelBase
	{
		#region EffectViewModelBase の実装

		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public override void Attach( int stream )
		{
			this._effect = new EffectChorus( stream ) { Feedback = this._feedback, Delay = this._delay, Depth = this._depth, WetDryMix = this._wetDryMix, IsEnabled = this.IsEnabled };
			this.Effect = this._effect;
		}

		#endregion

		#region プロパティ

		/// <summary>
		/// 音声の遅延時間を取得または設定します。
		/// </summary>
		public float Delay
		{
			get
			{
				return this._delay;
			}
			set
			{
				this._delay = value;
				if( this._effect != null )
				{
					this._effect.Delay = value;
				}

				this.NotifyPropertyChanged( "Delay" );
			}
		}

		/// <summary>
		/// 変調の割合を取得または設定します。
		/// </summary>
		public float Depth
		{
			get
			{
				return this._depth;
			}
			set
			{
				this._depth = value;
				if( this._effect != null )
				{
					this._effect.Depth = value;
				}

				this.NotifyPropertyChanged( "Depth" );
			}
		}

		/// <summary>
		/// 効果音をフィードバックさせる比率を取得または設定します。
		/// </summary>
		public float Feedback
		{
			get
			{
				return this._feedback;
			}
			set
			{
				this._feedback = value;
				if( this._effect != null )
				{
					this._effect.Feedback = value;
				}

				this.NotifyPropertyChanged( "Feedback" );
			}
		}

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分を取得または設定します。
		/// </summary>
		public float WetDryMix
		{
			get
			{
				return this._wetDryMix;
			}
			set
			{
				this._wetDryMix = value;
				if( this._effect != null )
				{
					this._effect.WetDryMix = value;
				}

				this.NotifyPropertyChanged( "WetDryMix" );
			}
		}

		#endregion

		
		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private EffectChorus _effect;

		/// <summary>
		/// 効果音音をフィードバックさせる比率。
		/// </summary>
		private float _feedback = EffectChorus.DefaultFeedback;

		/// <summary>
		/// 音声の遅延時間。
		/// </summary>
		private float _delay = EffectChorus.DefaultDelay;

		/// <summary>
		/// 変調の割合を取得または設定します。
		/// </summary>
		private float _depth = EffectChorus.DefaultDepth;

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分。
		/// </summary>
		private float _wetDryMix = EffectChorus.DefaultWetDryMix;

		#endregion
	}
}
