﻿using WpfAudioPlayer.Models.Audio;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音響効果の View と Model を仲介する共通クラスです。
	/// </summary>
	abstract class EffectViewModelBase : ViewModelBase
	{
		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public abstract void Attach( int stream );

		/// <summary>
		/// 音響効果を取得または設定します。
		/// </summary>
		protected IEffect Effect { get; set; }

		/// <summary>
		/// 音響効果が有効である事を示す値を取得または設定します。
		/// </summary>
		public bool IsEnabled
		{
			get
			{
				return this._isEnabled;
			}
			set
			{
				this._isEnabled = value;
				if( this.Effect != null )
				{
					this.Effect.IsEnabled = value;
				}

				this.NotifyPropertyChanged( "IsEnabled" );
			}
		}

		/// <summary>
		/// 音響効果の表示部分が展開されている事を示す値を取得または設定します。
		/// </summary>
		public bool IsExpanded
		{
			get
			{
				return this._isExpanded;
			}
			set
			{
				this._isExpanded = value;
				this.NotifyPropertyChanged( "IsExpanded" );
			}
		}

		/// <summary>
		/// 音響効果が有効である事を示す値。
		/// </summary>
		private bool _isEnabled;

		/// <summary>
		/// 音響効果の表示部分が展開されている事を示す値。
		/// </summary>
		private bool _isExpanded;
	}
}
