﻿using WpfAudioPlayer.Models.Audio;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音声のワイド効果の View と Model を仲介するクラスです。
	/// </summary>
	class EffectWideViewModel : EffectViewModelBase 
	{
		#region EffectViewModelBase の実装

		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public override void Attach( int stream )
		{
			this._effect = new EffectWide( stream ) { WetDry = this._wetDry, Wide = this._wide, IsEnabled = this.IsEnabled };
			this.Effect = this._effect;
		}

		#endregion

		#region プロパティ

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分を取得または設定します。
		/// </summary>
		public double WetDry
		{
			get
			{
				return this._wetDry;
			}
			set
			{
				this._wetDry = value;
				if( this._effect != null )
				{
					this._effect.WetDry = value;
				}

				this.NotifyPropertyChanged( "WetDry" );
			}
		}

		/// <summary>
		/// 音の広がりを取得または設定します。
		/// </summary>
		public double Wide
		{
			get
			{
				return this._wide;
			}
			set
			{
				this._wide = value;
				if( this._effect != null )
				{
					this._effect.Wide = value;
				}

				this.NotifyPropertyChanged( "Wide" );
			}
		}

		#endregion

		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private EffectWide _effect;

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分。
		/// </summary>
		private double _wetDry = EffectWide.DefaultWetDry;

		/// <summary>
		/// 音の広がり。
		/// </summary>
		private double _wide = EffectWide.DefaultWide;

		#endregion
	}
}
