﻿
namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音響効果の View と Model を仲介するクラスです。
	/// </summary>
	class EffectWindowViewModel : ViewModelBase
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		public EffectWindowViewModel()
		{
			this.EffectChorusViewModel     = new EffectChorusViewModel()     { IsEnabled = false, IsExpanded = true };
			this.EffectDelayViewModel      = new EffectDelayViewModel()      { IsEnabled = false, IsExpanded = true };
			this.EffectDistortionViewModel = new EffectDistortionViewModel() { IsEnabled = false, IsExpanded = true };
			this.EffectEchoViewModel       = new EffectEchoViewModel()       { IsEnabled = false, IsExpanded = true };
			this.EffectWideViewModel       = new EffectWideViewModel()       { IsEnabled = false, IsExpanded = true };
		}

		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public void Attach( int stream )
		{
			this.EffectChorusViewModel.Attach( stream );
			this.EffectDelayViewModel.Attach( stream );
			this.EffectDistortionViewModel.Attach( stream );
			this.EffectEchoViewModel.Attach( stream );
			this.EffectWideViewModel.Attach( stream );
		}

		/// <summary>
		/// コーラスを取得します。
		/// </summary>
		public EffectChorusViewModel EffectChorusViewModel { get; private set; }

		/// <summary>
		/// ディレイを取得します。
		/// </summary>
		public EffectDelayViewModel EffectDelayViewModel { get; private set; }

		/// <summary>
		/// ディストーションを取得します。
		/// </summary>
		public EffectDistortionViewModel EffectDistortionViewModel { get; private set; }

		/// <summary>
		/// エコーを取得します。
		/// </summary>
		public EffectEchoViewModel EffectEchoViewModel { get; private set; }

		/// <summary>
		/// ワイドを取得します。
		/// </summary>
		public EffectWideViewModel EffectWideViewModel { get; private set; }
	}
}
